diff_register_prompt

Function diff_register_prompt 

pub fn diff_register_prompt(
    state: &impl McpStateView,
    sender: AccountId,
    intent: &McpIntent,
    timestamp: u64,
) -> Result<StateDiff, String>
Compute the StateDiff for RegisterMcpPrompt. Deploys a prompt cell and registers it in the McpRegistry. Prompts go through the validator name registry for on-chain approval.